searchData={"items":[{"type":"module","title":"DaisyUIComponents","doc":"Reference this repository on your `mix.exs` file to start using.\n\n```elixir\ndef deps do\n  [\n    {:daisy_ui_components, \"~> 0.7\"}\n  ]\nend\n```\n\nAdd through `npm` the daisy UI package inside your phoenix application:\n\n```bash\ncd assets\nnpm i -D daisyui@latest\n```\n\nOn `tailwind.config.js` include Live DaisyUI Components under the content list and reference under plugins\n\n```javascript\nmodule.exports = {\n  content: [\n    //...\n    \"../deps/daisy_ui_components/**/*.*ex\" // <- reference DaisyUIComponents as content path\n  ],\n  //...\n  plugins: [\n    //...\n    // comment the tailwind form to not conflict with DaisyUI\n    // require(\"@tailwindcss/forms\"),\n    require(\"daisyui\")  <- // add daisyUI plugin\n    //...\n  ]\n}\n```\n\nAdd error translation function to your app's config.exs file. This function is used to translate ecto changeset errors\n\n```elixir\nconfig :daisy_ui_components, translate_function: &MyAppWeb.CoreComponents.translate_error/1\n```\n\nAnd now this library is ready. To have the components available under liveview, import the components on the web folder\n\n```elixir\ndefp html_helpers do\n  quote do\n    # Translation\n    use Gettext, backend: MyAppWeb.Gettext\n\n    # HTML escaping functionality\n    import Phoenix.HTML\n\n    # Import DaisyUI components into your project\n    use DaisyUIComponents\n\n    # Comment your own CoreComponents to not conflict with the defaults of this library.\n    # import YourProjectWeb.CoreComponents\n    # Importing CoreComponents from your project is no longer necessary since\n    # DaisyUIComponents.CoreComponents offers a drop in replacement\n    # If you still want to use your own core components, remember to delete the default components generated from phoenix in this file\n    # ...\n  end\nend\n```\n\nFinally, in order to not conflict with some of the DaisyUI default styles, remove the `bg-white` class in your `root.html.heex` file.\n\n```heex","ref":"DaisyUIComponents.html"},{"type":"module","title":"Change from this - DaisyUIComponents","doc":"","ref":"DaisyUIComponents.html#module-change-from-this"},{"type":"module","title":"to this - DaisyUIComponents","doc":"```","ref":"DaisyUIComponents.html#module-to-this"},{"type":"module","title":"⭐ Core Components - DaisyUIComponents","doc":"This library aims to integrate seamlessly with Phoenix generators. For this reason you don't need the components inside the `CoreComponents` after adding `use DaisyUIComponents` into your web file.\nAll the components should be compatible, styled with DaisyUI.\n\nIf you encounter any compatibility issues, feel free to open an `issue` or submit a `pull request`, and I'll take a look.","ref":"DaisyUIComponents.html#module-core-components"},{"type":"module","title":"🤖 Liveview 1.0 - DaisyUIComponents","doc":"This project is fully compatible with the Liveview 1.0 🔥. If you are using a previous Liveview version, check the [migration guide](https://github.com/phoenixframework/phoenix_live_view/blob/v1.0/CHANGELOG.md).","ref":"DaisyUIComponents.html#module-liveview-1-0"},{"type":"module","title":"📦 NPM setup - DaisyUIComponents","doc":"Since DaisyUI requires `npm` to install, it's also necessary to configure in your project the asset pipeline to use the npm commands.\n\nIn your `mix.exs` file, add the npm command in your assets setup:\n\n```diff\n\"assets.setup\": [\n  \"tailwind.install --if-missing\",\n- \"esbuild.install --if-missing\"\n+ \"esbuild.install --if-missing\",\n+ \"cmd npm install --prefix assets\"\n]\n```\n\nand if you are deploying the application with `Docker`, run the npm scripts there too:\n\n```diff\n# install build dependencies\n-RUN apt-get update -y && apt-get install -y build-essential git \\\n+RUN apt-get update -y && apt-get install -y build-essential git npm \\\n    && apt-get clean && rm -f /var/lib/apt/lists/*_*\n\n# ...\nRUN mix deps.compile\n\n# build assets\n+COPY assets/package.json assets/package-lock.json ./assets/\n+RUN npm --prefix ./assets ci --progress=false --no-audit --loglevel=error\n```","ref":"DaisyUIComponents.html#module-npm-setup"},{"type":"module","title":"⚡️ Components - DaisyUIComponents","doc":"List of available components.","ref":"DaisyUIComponents.html#module-components"},{"type":"module","title":"Actions - DaisyUIComponents","doc":"| Component                                                            | Status | Storybook |\n| -------------------------------------------------------------------- | ------ | --------- |\n| [Button](https://daisyui.com/components/button)                      | ✅     | ✅        |\n| [Dropdown](https://daisyui.com/components/dropdown)                  | ✅     | ✅        |\n| [Modal](https://daisyui.com/components/modal)                        | ✅     | ✅        |\n| [Swap](https://daisyui.com/components/swap)                          | ✅     | ✅        |\n| [Theme Controller](https://daisyui.com/components/theme-controller/) | ❌     | ❌        |","ref":"DaisyUIComponents.html#module-actions"},{"type":"module","title":"Data Display - DaisyUIComponents","doc":"| Component                                             | Status | Storybook |\n| ----------------------------------------------------- | ------ | --------- |\n| [Accordion](https://daisyui.com/components/accordion) | ❌     | ❌        |\n| [Avatar](https://daisyui.com/components/avatar)       | ✅     | ✅        |\n| [Badge](https://daisyui.com/components/badge)         | ✅     | ✅        |\n| [Card](https://daisyui.com/components/card)           | ✅     | ✅        |\n| [Carousel](https://daisyui.com/components/carousel)   | ❌     | ❌        |\n| [Chat bubble](https://daisyui.com/components/chat)    | ❌     | ❌        |\n| [Collapse](https://daisyui.com/components/collapse)   | ❌     | ❌        |\n| [Countdown](https://daisyui.com/components/countdown) | ❌     | ❌        |\n| [Diff](https://daisyui.com/components/diff/)          | ❌     | ❌        |\n| [Kbd](https://daisyui.com/components/kbd)             | ❌     | ❌        |\n| [Stat](https://daisyui.com/components/stat)           | ✅     | ✅        |\n| [Table](https://daisyui.com/components/table)         | ✅     | ✅        |\n| [Timeline](https://daisyui.com/components/timeline/)  | ❌     | ❌        |","ref":"DaisyUIComponents.html#module-data-display"},{"type":"module","title":"Navigation - DaisyUIComponents","doc":"| Component                                                              | Status | Storybook |\n| ---------------------------------------------------------------------- | ------ | --------- |\n| [Breadcrumbs](https://daisyui.com/components/breadcrumbs)              | ✅     | ✅        |\n| [Bottom navigation](https://daisyui.com/components/bottom-navigation/) | ❌     | ❌        |\n| [Link](https://daisyui.com/components/link)                            | ❌     | ❌        |\n| [Menu](https://daisyui.com/components/menu)                            | ✅     | ✅        |\n| [Navbar](https://daisyui.com/components/navbar)                        | ✅     | ✅        |\n| [Pagination](https://daisyui.com/components/pagination)                | ✅     | ✅        |\n| [Steps](https://daisyui.com/components/steps)                          | ❌     | ❌        |\n| [Tabs](https://daisyui.com/components/tab)                             | ❌     | ❌        |","ref":"DaisyUIComponents.html#module-navigation"},{"type":"module","title":"Feedback - DaisyUIComponents","doc":"| Component                                                         | Status | Storybook |\n| ----------------------------------------------------------------- | ------ | --------- |\n| [Alert](https://daisyui.com/components/alert)                     | ✅     | ✅        |\n| [Loading](https://daisyui.com/components/loading/)                | ✅     | ✅        |\n| [Progress](https://daisyui.com/components/progress)               | ❌     | ❌        |\n| [Radial progress](https://daisyui.com/components/radial-progress) | ❌     | ❌        |\n| [Skeleton](https://daisyui.com/components/skeleton/)              | ❌     | ❌        |\n| [Toast](https://daisyui.com/components/toast)                     | ❌     | ❌        |\n| [Tooltip](https://daisyui.com/components/tooltip)                 | ✅     | ✅        |","ref":"DaisyUIComponents.html#module-feedback"},{"type":"module","title":"Data Input - DaisyUIComponents","doc":"| Component                                               | Status | Storybook |\n| ------------------------------------------------------- | ------ | --------- |\n| [Checkbox](https://daisyui.com/components/checkbox)     | ✅     | ✅        |\n| [File input](https://daisyui.com/components/file-input) | ❌     | ❌        |\n| [Radio](https://daisyui.com/components/radio)           | ✅     | ✅        |\n| [Range](https://daisyui.com/components/range)           | ✅     | ✅        |\n| [Rating](https://daisyui.com/components/rating)         | ❌     | ❌        |\n| [Select](https://daisyui.com/components/select)         | ✅     | ✅        |\n| [Text Input](https://daisyui.com/components/input)      | ✅     | ✅        |\n| [Textarea](https://daisyui.com/components/textarea)     | ✅     | ✅        |\n| [Toggle](https://daisyui.com/components/toggle)         | ✅     | ✅        |","ref":"DaisyUIComponents.html#module-data-input"},{"type":"module","title":"Layout - DaisyUIComponents","doc":"| Component                                             | Status | Storybook |\n| ----------------------------------------------------- | ------ | --------- |\n| [Artboard](https://daisyui.com/components/artboard)   | ❌     | ❌        |\n| [Divider](https://daisyui.com/components/divider)     | ❌     | ❌        |\n| [Drawer](https://daisyui.com/components/drawer)       | ✅     | ✅        |\n| [Footer](https://daisyui.com/components/footer)       | ❌     | ❌        |\n| [Hero](https://daisyui.com/components/hero)           | ❌     | ❌        |\n| [Indicator](https://daisyui.com/components/indicator) | ❌     | ❌        |\n| [Join](https://daisyui.com/components/join)           | ✅     | ❌        |\n| [Mask](https://daisyui.com/components/mask)           | ❌     | ❌        |\n| [Stack](https://daisyui.com/components/stack)         | ❌     | ❌        |","ref":"DaisyUIComponents.html#module-layout"},{"type":"module","title":"Mockup - DaisyUIComponents","doc":"| Component                                                 | Status | Storybook |\n| --------------------------------------------------------- | ------ | --------- |\n| [Browser](https://daisyui.com/components/mockup-browser/) | ❌     | ❌        |\n| [Code](https://daisyui.com/components/mockup-code)        | ❌     | ❌        |\n| [Phone](https://daisyui.com/components/mockup-phone)      | ❌     | ❌        |\n| [Window](https://daisyui.com/components/mockup-window)    | ❌     | ❌        |","ref":"DaisyUIComponents.html#module-mockup"},{"type":"module","title":"Phoenix Core Components - DaisyUIComponents","doc":"| Component   | Status | Storybook |\n| ----------- | ------ | --------- |\n| Flash       | ✅     | ✅        |\n| Header      | ✅     | ✅        |\n| List        | ✅     | ✅        |\n| Simple Form | ✅     | ✅        |\n| Input       | ✅     | ✅        |\n| Table       | ✅     | ✅        |","ref":"DaisyUIComponents.html#module-phoenix-core-components"},{"type":"module","title":"🗺️ Roadmap - DaisyUIComponents","doc":"- Implement all components\n- Document all components in Storybook\n- Create `mix` script to enable users to import the components of this library into their projects, sharing the same project namespace.","ref":"DaisyUIComponents.html#module-roadmap"},{"type":"macro","title":"DaisyUIComponents.__using__/1","doc":"Used for functional or live components","ref":"DaisyUIComponents.html#__using__/1"},{"type":"module","title":"DaisyUIComponents.JSHelpers","doc":"Common JS functions from [Phoenix Core Components](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.JSHelpers.html"},{"type":"function","title":"DaisyUIComponents.JSHelpers.hide/2","doc":"","ref":"DaisyUIComponents.JSHelpers.html#hide/2"},{"type":"function","title":"DaisyUIComponents.JSHelpers.show/2","doc":"","ref":"DaisyUIComponents.JSHelpers.html#show/2"},{"type":"module","title":"DaisyUIComponents.Alert","doc":"Alert component\n\nhttps://daisyui.com/components/alert","ref":"DaisyUIComponents.Alert.html"},{"type":"function","title":"DaisyUIComponents.Alert.alert/1","doc":"","ref":"DaisyUIComponents.Alert.html#alert/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Alert.alert/1","doc":"* `id` (`:string`) - the optional id of alert container. Defaults to `nil`.\n* `class` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Alert.html#alert/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Alert.alert/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Alert.html#alert/1-slots"},{"type":"function","title":"DaisyUIComponents.Alert.flash/1","doc":"Renders flash notices.","ref":"DaisyUIComponents.Alert.html#flash/1"},{"type":"function","title":"Examples - DaisyUIComponents.Alert.flash/1","doc":"<.flash kind={:info} flash={@flash} />\n    <.flash kind={:info} phx-mounted={show(\"#flash\")}>Welcome Back!</.flash>","ref":"DaisyUIComponents.Alert.html#flash/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Alert.flash/1","doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:atom`) - Defaults to `:top_right`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"DaisyUIComponents.Alert.html#flash/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Alert.flash/1","doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"DaisyUIComponents.Alert.html#flash/1-slots"},{"type":"function","title":"DaisyUIComponents.Alert.flash_group/1","doc":"Shows the flash group with standard titles and content.","ref":"DaisyUIComponents.Alert.html#flash_group/1"},{"type":"function","title":"Examples - DaisyUIComponents.Alert.flash_group/1","doc":"<.flash_group flash={@flash} />","ref":"DaisyUIComponents.Alert.html#flash_group/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Alert.flash_group/1","doc":"* `id` (`:string`) - the optional id of flash container. Defaults to `\"flash-group\"`.\n* `flash` (`:map`) (required) - the map of flash messages.\n* `direction` (`:atom`) - Defaults to `:top_right`.","ref":"DaisyUIComponents.Alert.html#flash_group/1-attributes"},{"type":"module","title":"DaisyUIComponents.Avatar","doc":"Avatar component\n\nhttps://daisyui.com/components/avatar","ref":"DaisyUIComponents.Avatar.html"},{"type":"function","title":"DaisyUIComponents.Avatar.avatar/1","doc":"","ref":"DaisyUIComponents.Avatar.html#avatar/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Avatar.avatar/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `placeholder` (`:boolean`) - Defaults to `false`.\n* `online` (`:boolean`) - Defaults to `false`.\n* `offline` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Avatar.html#avatar/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Avatar.avatar/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Avatar.html#avatar/1-slots"},{"type":"function","title":"DaisyUIComponents.Avatar.avatar_group/1","doc":"","ref":"DaisyUIComponents.Avatar.html#avatar_group/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Avatar.avatar_group/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Avatar.html#avatar_group/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Avatar.avatar_group/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Avatar.html#avatar_group/1-slots"},{"type":"module","title":"DaisyUIComponents.Back","doc":"This component was extracted from the original [Phoenix CoreComponents](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.Back.html"},{"type":"function","title":"DaisyUIComponents.Back.back/1","doc":"Renders a back navigation link.","ref":"DaisyUIComponents.Back.html#back/1"},{"type":"function","title":"Examples - DaisyUIComponents.Back.back/1","doc":"<.back navigate={~p\"/posts\"}>Back to posts</.back>","ref":"DaisyUIComponents.Back.html#back/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Back.back/1","doc":"* `navigate` (`:any`) (required)","ref":"DaisyUIComponents.Back.html#back/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Back.back/1","doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Back.html#back/1-slots"},{"type":"module","title":"DaisyUIComponents.Badge","doc":"Badge component\n\nhttps://daisyui.com/components/badge/","ref":"DaisyUIComponents.Badge.html"},{"type":"function","title":"DaisyUIComponents.Badge.badge/1","doc":"Renders a badge.","ref":"DaisyUIComponents.Badge.html#badge/1"},{"type":"function","title":"Examples - DaisyUIComponents.Badge.badge/1","doc":"<.badge>Default</.badge>\n    <.badge primary class=\"gap-2\">Primary</.badge>","ref":"DaisyUIComponents.Badge.html#badge/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Badge.badge/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, `\"error\"`, or `\"neutral\"`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `outline` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Badge.html#badge/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Badge.badge/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Badge.html#badge/1-slots"},{"type":"module","title":"DaisyUIComponents.Breadcrumbs","doc":"Stat component\n\nhttps://daisyui.com/components/stat","ref":"DaisyUIComponents.Breadcrumbs.html"},{"type":"function","title":"DaisyUIComponents.Breadcrumbs.breadcrumbs/1","doc":"","ref":"DaisyUIComponents.Breadcrumbs.html#breadcrumbs/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Breadcrumbs.breadcrumbs/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Breadcrumbs.html#breadcrumbs/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Breadcrumbs.breadcrumbs/1","doc":"* `item` - Accepts attributes:\n\n  * `icon` (`:string`)\n  * `path` (`:string`)\n* `inner_block`","ref":"DaisyUIComponents.Breadcrumbs.html#breadcrumbs/1-slots"},{"type":"module","title":"DaisyUIComponents.Button","doc":"Button component\n\nhttps://daisyui.com/components/button/","ref":"DaisyUIComponents.Button.html"},{"type":"function","title":"DaisyUIComponents.Button.button/1","doc":"Renders a button.","ref":"DaisyUIComponents.Button.html#button/1"},{"type":"function","title":"Examples - DaisyUIComponents.Button.button/1","doc":"<.button>Send!</.button>\n    <.button phx-click=\"go\" class=\"ml-2\">Send!</.button>","ref":"DaisyUIComponents.Button.html#button/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Button.button/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, `\"error\"`, or `\"neutral\"`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `link` (`:boolean`) - Defaults to `false`.\n* `outline` (`:boolean`) - Defaults to `false`.\n* `active` (`:boolean`) - Defaults to `false`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* `glass` (`:boolean`) - Defaults to `false`.\n* `loading` (`:boolean`) - Defaults to `false`.\n* `no_animation` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `wide` (`:boolean`) - Defaults to `false`.\n* `block` (`:boolean`) - Defaults to `false`.\n* `shape` (`:string`) - Must be one of `\"circle\"`, or `\"square\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"form\", \"name\", \"value\"]`.","ref":"DaisyUIComponents.Button.html#button/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Button.button/1","doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Button.html#button/1-slots"},{"type":"module","title":"DaisyUIComponents.Card","doc":"Card component\n\nhttps://daisyui.com/components/card/","ref":"DaisyUIComponents.Card.html"},{"type":"function","title":"DaisyUIComponents.Card.card/1","doc":"","ref":"DaisyUIComponents.Card.html#card/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Card.card/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `placement` (`:string`) - Must be one of `\"top\"`, or `\"bottom\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `modifier` (`:string`) - Must be one of `\"side\"`, or `\"image_full\"`.\n* `padding` (`:string`) - Must be one of `\"normal\"`, or `\"compact\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Card.card/1","doc":"* `card_title` - Accepts attributes:\n\n  * `class` (`:any`)\n* `card_actions`\n* `card_body`\n* `inner_block`","ref":"DaisyUIComponents.Card.html#card/1-slots"},{"type":"function","title":"DaisyUIComponents.Card.card_actions/1","doc":"","ref":"DaisyUIComponents.Card.html#card_actions/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Card.card_actions/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_actions/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Card.card_actions/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_actions/1-slots"},{"type":"function","title":"DaisyUIComponents.Card.card_body/1","doc":"","ref":"DaisyUIComponents.Card.html#card_body/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Card.card_body/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_body/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Card.card_body/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_body/1-slots"},{"type":"function","title":"DaisyUIComponents.Card.card_title/1","doc":"","ref":"DaisyUIComponents.Card.html#card_title/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Card.card_title/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `label` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_title/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Card.card_title/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_title/1-slots"},{"type":"function","title":"DaisyUIComponents.Card.modifiers/0","doc":"","ref":"DaisyUIComponents.Card.html#modifiers/0"},{"type":"function","title":"DaisyUIComponents.Card.paddings/0","doc":"","ref":"DaisyUIComponents.Card.html#paddings/0"},{"type":"function","title":"DaisyUIComponents.Card.placements/0","doc":"","ref":"DaisyUIComponents.Card.html#placements/0"},{"type":"module","title":"DaisyUIComponents.Checkbox","doc":"Checkbox component\n\nhttps://daisyui.com/components/checkbox","ref":"DaisyUIComponents.Checkbox.html"},{"type":"function","title":"DaisyUIComponents.Checkbox.checkbox/1","doc":"","ref":"DaisyUIComponents.Checkbox.html#checkbox/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Checkbox.checkbox/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs. Defaults to `nil`.\n* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Checkbox.html#checkbox/1-attributes"},{"type":"module","title":"DaisyUIComponents.Drawer","doc":"Drawer component\n\nhttps://daisyui.com/components/drawer","ref":"DaisyUIComponents.Drawer.html"},{"type":"function","title":"DaisyUIComponents.Drawer.drawer/1","doc":"","ref":"DaisyUIComponents.Drawer.html#drawer/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Drawer.drawer/1","doc":"* `selector_id` (`:string`) (required) - identifier to toggle the modal.\n* `class` (`:any`) - Defaults to `nil`.\n* `open` (`:boolean`) - Forces the drawer to be open. Defaults to `nil`.\n* `end` (`:boolean`) - Puts drawer to the right. Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Drawer.html#drawer/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Drawer.drawer/1","doc":"* `drawer_content` - Accepts attributes:\n\n  * `class` (`:any`)\n* `drawer_side` - Accepts attributes:\n\n  * `class` (`:any`)\n* `inner_block`","ref":"DaisyUIComponents.Drawer.html#drawer/1-slots"},{"type":"function","title":"DaisyUIComponents.Drawer.drawer_content/1","doc":"","ref":"DaisyUIComponents.Drawer.html#drawer_content/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Drawer.drawer_content/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Drawer.html#drawer_content/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Drawer.drawer_content/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Drawer.html#drawer_content/1-slots"},{"type":"function","title":"DaisyUIComponents.Drawer.drawer_side/1","doc":"","ref":"DaisyUIComponents.Drawer.html#drawer_side/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Drawer.drawer_side/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `selector_id` (`:string`) (required) - identifier to toggle the modal.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Drawer.html#drawer_side/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Drawer.drawer_side/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Drawer.html#drawer_side/1-slots"},{"type":"module","title":"DaisyUIComponents.Dropdown","doc":"Dropdown component\n\nhttps://daisyui.com/components/dropdown/","ref":"DaisyUIComponents.Dropdown.html"},{"type":"function","title":"DaisyUIComponents.Dropdown.dropdown/1","doc":"Renders a  dropdown","ref":"DaisyUIComponents.Dropdown.html#dropdown/1"},{"type":"function","title":"Examples - DaisyUIComponents.Dropdown.dropdown/1","doc":"<.dropdown>\n       open or close \n       \n          Item 1  \n          Item 2  \n       \n    </.dropdown>","ref":"DaisyUIComponents.Dropdown.html#dropdown/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Dropdown.dropdown/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"top\"`, `\"bottom\"`, `\"left\"`, or `\"right\"`.\n* `align` (`:string`) - Must be one of `\"end\"`.\n* `hover` (`:boolean`) - Defaults to `nil`.\n* `open` (`:boolean`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Dropdown.html#dropdown/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Dropdown.dropdown/1","doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Dropdown.html#dropdown/1-slots"},{"type":"module","title":"DaisyUIComponents.Form","doc":"Form component helpers","ref":"DaisyUIComponents.Form.html"},{"type":"function","title":"DaisyUIComponents.Form.error/1","doc":"Generates a generic error message.","ref":"DaisyUIComponents.Form.html#error/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Form.error/1","doc":"* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].","ref":"DaisyUIComponents.Form.html#error/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Form.error/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Form.html#error/1-slots"},{"type":"function","title":"DaisyUIComponents.Form.form_input/1","doc":"Renders an input with label and error messages.\n\nA `%Phoenix.HTML.Form{}` and field name may be passed to the input\nto build input names and error messages, or all the attributes and\nerrors may be passed explicitly.","ref":"DaisyUIComponents.Form.html#form_input/1"},{"type":"function","title":"Examples - DaisyUIComponents.Form.form_input/1","doc":"<.form_input field={@form[:email]} type=\"email\" />\n    <.form_input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"DaisyUIComponents.Form.html#form_input/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Form.form_input/1","doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`) - Defaults to `nil`.\n* `value` (`:any`)\n* `color` (`:string`) - Defaults to `nil`.\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `class` (`:string`) - Defaults to `nil`.\n* `bordered` (`:boolean`) - Defaults to `true`.\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"DaisyUIComponents.Form.html#form_input/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Form.form_input/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Form.html#form_input/1-slots"},{"type":"function","title":"DaisyUIComponents.Form.label/1","doc":"Renders a label.","ref":"DaisyUIComponents.Form.html#label/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Form.label/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `for` (`:string`) - Defaults to `nil`.\n* `type` (`:string`) - Defaults to `\"label\"`.\n* `label` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Form.html#label/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Form.label/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Form.html#label/1-slots"},{"type":"function","title":"DaisyUIComponents.Form.simple_form/1","doc":"Renders a simple form.\nThis component was extracted from the original [Phoenix CoreComponents](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.Form.html#simple_form/1"},{"type":"function","title":"Examples - DaisyUIComponents.Form.simple_form/1","doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.input field={@form[:email]} label=\"Email\"/>\n      <.input field={@form[:username]} label=\"Username\" />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"DaisyUIComponents.Form.html#simple_form/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Form.simple_form/1","doc":"* `for` (`:any`) (required) - the datastructure for the form.\n* `as` (`:any`) - the server side parameter to collect all input under. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to apply to the form tag. Supports all globals plus: `[\"autocomplete\", \"name\", \"rel\", \"action\", \"enctype\", \"method\", \"novalidate\", \"target\"]`.","ref":"DaisyUIComponents.Form.html#simple_form/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Form.simple_form/1","doc":"* `inner_block` (required)\n* `actions` - the slot for form actions, such as a submit button.","ref":"DaisyUIComponents.Form.html#simple_form/1-slots"},{"type":"module","title":"DaisyUIComponents.Header","doc":"This component was extracted from the original [Phoenix CoreComponents](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.Header.html"},{"type":"function","title":"DaisyUIComponents.Header.header/1","doc":"Renders a header with title.","ref":"DaisyUIComponents.Header.html#header/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Header.header/1","doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.Header.html#header/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Header.header/1","doc":"* `inner_block` (required)\n* `subtitle`\n* `actions`","ref":"DaisyUIComponents.Header.html#header/1-slots"},{"type":"module","title":"DaisyUIComponents.Icon","doc":"Renders hero icons\nCode extracted from [Phoenix Core Components](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.Icon.html"},{"type":"function","title":"DaisyUIComponents.Icon.icon/1","doc":"Renders a [Hero Icon](https://heroicons.com).\n\nHero icons come in three styles – outline, solid, and mini.\nBy default, the outline style is used, but solid and mini may\nbe applied by using the `-solid` and `-mini` suffix.\n\nYou can customize the size and colors of the icons by setting\nwidth, height, and background color classes.\n\nIcons are extracted from your `assets/vendor/heroicons` directory and bundled\nwithin your compiled app.css by the plugin in your `assets/tailwind.config.js`.","ref":"DaisyUIComponents.Icon.html#icon/1"},{"type":"function","title":"Examples - DaisyUIComponents.Icon.icon/1","doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 animate-spin\" />","ref":"DaisyUIComponents.Icon.html#icon/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Icon.icon/1","doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.Icon.html#icon/1-attributes"},{"type":"module","title":"DaisyUIComponents.Input","doc":"Generic Input component","ref":"DaisyUIComponents.Input.html"},{"type":"function","title":"DaisyUIComponents.Input.input/1","doc":"Renders a generic input based on type.","ref":"DaisyUIComponents.Input.html#input/1"},{"type":"function","title":"Examples - DaisyUIComponents.Input.input/1","doc":"<.input type=\"email\" />\n    <.input name=\"my-input\" type=\"checkbox\" value=\"false\" />","ref":"DaisyUIComponents.Input.html#input/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Input.input/1","doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`)\n* `value` (`:any`)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `color` (`:string`) - Defaults to `nil`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `class` (`:string`) - Defaults to `nil`.\n* `bordered` (`:boolean`) - Defaults to `nil`.\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"DaisyUIComponents.Input.html#input/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Input.input/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Input.html#input/1-slots"},{"type":"module","title":"DaisyUIComponents.Join","doc":"Button Group component\n\nhttps://daisyui.com/components/join/","ref":"DaisyUIComponents.Join.html"},{"type":"function","title":"DaisyUIComponents.Join.directions/0","doc":"","ref":"DaisyUIComponents.Join.html#directions/0"},{"type":"function","title":"DaisyUIComponents.Join.join/1","doc":"Join elements","ref":"DaisyUIComponents.Join.html#join/1"},{"type":"function","title":"Examples - DaisyUIComponents.Join.join/1","doc":"<.join>\n      <.button class=\"join-item\" active>Button</.button>\n      <.button class=\"join-item\">Button</.button>\n      <.button class=\"join-item\">Button</.button>\n    </.join>","ref":"DaisyUIComponents.Join.html#join/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Join.join/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Join.html#join/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Join.join/1","doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Join.html#join/1-slots"},{"type":"module","title":"DaisyUIComponents.List","doc":"This component was extracted from the original [Phoenix CoreComponents](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.List.html"},{"type":"function","title":"DaisyUIComponents.List.list/1","doc":"Renders a data list.","ref":"DaisyUIComponents.List.html#list/1"},{"type":"function","title":"Examples - DaisyUIComponents.List.list/1","doc":"<.list>\n      <:item title=\"Title\"><%= @post.title %></:item>\n      <:item title=\"Views\"><%= @post.views %></:item>\n    </.list>","ref":"DaisyUIComponents.List.html#list/1-examples"},{"type":"function","title":"Slots - DaisyUIComponents.List.list/1","doc":"* `item` (required) - Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"DaisyUIComponents.List.html#list/1-slots"},{"type":"module","title":"DaisyUIComponents.Loading","doc":"Loading component\n\nhttps://daisyui.com/components/loading/","ref":"DaisyUIComponents.Loading.html"},{"type":"function","title":"DaisyUIComponents.Loading.loading/1","doc":"Renders a loading.","ref":"DaisyUIComponents.Loading.html#loading/1"},{"type":"function","title":"Examples - DaisyUIComponents.Loading.loading/1","doc":"<.loading></.loading>\n    <.loading phx-click=\"go\" shape=\"infinity\" color=\"warning\" size=\"lg\" ></.loading>","ref":"DaisyUIComponents.Loading.html#loading/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Loading.loading/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `shape` (`:string`) (required) - Must be one of `\"spinner\"`, `\"dots\"`, `\"ring\"`, `\"ball\"`, `\"bars\"`, or `\"infinity\"`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, `\"error\"`, or `\"neutral\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"id\"]`.","ref":"DaisyUIComponents.Loading.html#loading/1-attributes"},{"type":"module","title":"DaisyUIComponents.Menu","doc":"Menu component\n\nhttps://daisyui.com/components/menu","ref":"DaisyUIComponents.Menu.html"},{"type":"function","title":"DaisyUIComponents.Menu.directions/0","doc":"","ref":"DaisyUIComponents.Menu.html#directions/0"},{"type":"function","title":"DaisyUIComponents.Menu.menu/1","doc":"","ref":"DaisyUIComponents.Menu.html#menu/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Menu.menu/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Menu.html#menu/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Menu.menu/1","doc":"* `item` - Accepts attributes:\n\n  * `class` (`:any`)\n* `inner_block`","ref":"DaisyUIComponents.Menu.html#menu/1-slots"},{"type":"module","title":"DaisyUIComponents.Modal","doc":"Modal component\n\nhttps://daisyui.com/components/modal/","ref":"DaisyUIComponents.Modal.html"},{"type":"function","title":"DaisyUIComponents.Modal.hide_modal/2","doc":"","ref":"DaisyUIComponents.Modal.html#hide_modal/2"},{"type":"function","title":"DaisyUIComponents.Modal.modal/1","doc":"Renders a dialog modal.","ref":"DaisyUIComponents.Modal.html#modal/1"},{"type":"function","title":"Examples - DaisyUIComponents.Modal.modal/1","doc":"<.modal id=\"confirm-modal\">\n      This is a modal\n    </.modal>\n\nJS commands may be passed to the `:on_cancel` to configure\nthe closing/cancel event, for example:\n\n    <.modal id=\"confirm\" on_cancel={JS.navigate(~p\"/posts\")}>\n      This is another modal\n    </.modal>\n\ndialog with slots and actions:\n\n    <.modal id=\"confirm\">\n      <:modal_box class=\"w-11/12 max-w-5xl\">\n        Modal to confirm\n        <.modal_action>\n          <.button>Confirm</.button>\n        </.modal_action>\n      </:modal_box>\n    </.modal>","ref":"DaisyUIComponents.Modal.html#modal/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Modal.modal/1","doc":"* `id` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.\n* `open` (`:boolean`) - Defaults to `false`.\n* `show` (`:boolean`) - Behaves like `open` attribute. This attribute exist to avoid compatibility issues with phoenix core components. Defaults to `nil`.\n* `closeable` (`:boolean`) - Defaults to `true`.\n* `close_on_click_away` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Modal.html#modal/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Modal.modal/1","doc":"* `modal_box` - the slot for compacting the modal body. Accepts attributes:\n\n  * `class` (`:string`)\n  * `content_class` (`:string`)\n* `inner_block`","ref":"DaisyUIComponents.Modal.html#modal/1-slots"},{"type":"function","title":"DaisyUIComponents.Modal.modal_action/1","doc":"","ref":"DaisyUIComponents.Modal.html#modal_action/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Modal.modal_action/1","doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.Modal.html#modal_action/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Modal.modal_action/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Modal.html#modal_action/1-slots"},{"type":"function","title":"DaisyUIComponents.Modal.modal_box/1","doc":"","ref":"DaisyUIComponents.Modal.html#modal_box/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Modal.modal_box/1","doc":"* `modal_id` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.\n* `content_class` (`:string`) - Defaults to `nil`.\n* `closeable` (`:boolean`) - Defaults to `true`.\n* `close_on_click_away` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Modal.html#modal_box/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Modal.modal_box/1","doc":"* `inner_block`\n* `actions` - the slot for showing modal actions.","ref":"DaisyUIComponents.Modal.html#modal_box/1-slots"},{"type":"function","title":"DaisyUIComponents.Modal.show_modal/2","doc":"","ref":"DaisyUIComponents.Modal.html#show_modal/2"},{"type":"module","title":"DaisyUIComponents.Navbar","doc":"Navbar component\n\nhttps://daisyui.com/components/navbar/","ref":"DaisyUIComponents.Navbar.html"},{"type":"function","title":"DaisyUIComponents.Navbar.navbar/1","doc":"","ref":"DaisyUIComponents.Navbar.html#navbar/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Navbar.navbar/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Navbar.navbar/1","doc":"* `navbar_start` - Accepts attributes:\n\n  * `class` (`:any`)\n* `navbar_center` - Accepts attributes:\n\n  * `class` (`:any`)\n* `navbar_end` - Accepts attributes:\n\n  * `class` (`:any`)\n* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar/1-slots"},{"type":"function","title":"DaisyUIComponents.Navbar.navbar_center/1","doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_center/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Navbar.navbar_center/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_center/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Navbar.navbar_center/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_center/1-slots"},{"type":"function","title":"DaisyUIComponents.Navbar.navbar_end/1","doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_end/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Navbar.navbar_end/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_end/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Navbar.navbar_end/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_end/1-slots"},{"type":"function","title":"DaisyUIComponents.Navbar.navbar_start/1","doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_start/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Navbar.navbar_start/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_start/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Navbar.navbar_start/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_start/1-slots"},{"type":"module","title":"DaisyUIComponents.Pagination","doc":"Button Group component\n\nhttps://daisyui.com/components/pagination/","ref":"DaisyUIComponents.Pagination.html"},{"type":"function","title":"DaisyUIComponents.Pagination.calculate_display_btn/3","doc":"","ref":"DaisyUIComponents.Pagination.html#calculate_display_btn/3"},{"type":"function","title":"DaisyUIComponents.Pagination.pagination/1","doc":"Renders a button group.","ref":"DaisyUIComponents.Pagination.html#pagination/1"},{"type":"function","title":"Examples - DaisyUIComponents.Pagination.pagination/1","doc":"<.pagination page={1} page_size={10} total_entries={100} />","ref":"DaisyUIComponents.Pagination.html#pagination/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Pagination.pagination/1","doc":"* `page` (`:integer`) - Defaults to `1`.\n* `page_size` (`:integer`) - Defaults to `10`.\n* `total_entries` (`:integer`) - Defaults to `100`.\n* `button_class` (`:string`) - Defaults to `nil`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `target` (`:string`) - Defaults to `nil`.\n* `page_click_event` (`:string`) - Defaults to `\"page_click\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Pagination.html#pagination/1-attributes"},{"type":"module","title":"DaisyUIComponents.Radio","doc":"Checkbox component\n\nhttps://daisyui.com/components/radio","ref":"DaisyUIComponents.Radio.html"},{"type":"function","title":"DaisyUIComponents.Radio.radio/1","doc":"","ref":"DaisyUIComponents.Radio.html#radio/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Radio.radio/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `checked` (`:boolean`) - the checked flag for radio inputs. Defaults to `nil`.\n* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Radio.html#radio/1-attributes"},{"type":"module","title":"DaisyUIComponents.Range","doc":"Select component\n\nhttps://daisyui.com/components/range","ref":"DaisyUIComponents.Range.html"},{"type":"function","title":"DaisyUIComponents.Range.range/1","doc":"","ref":"DaisyUIComponents.Range.html#range/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Range.range/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `min` (`:integer`) - Defaults to `nil`.\n* `max` (`:integer`) - Defaults to `nil`.\n* `step` (`:integer`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Range.html#range/1-attributes"},{"type":"module","title":"DaisyUIComponents.Select","doc":"Select component\n\nhttps://daisyui.com/components/select","ref":"DaisyUIComponents.Select.html"},{"type":"function","title":"DaisyUIComponents.Select.select/1","doc":"","ref":"DaisyUIComponents.Select.html#select/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Select.select/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `value` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"value\", \"multiple\"]`.","ref":"DaisyUIComponents.Select.html#select/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Select.select/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Select.html#select/1-slots"},{"type":"module","title":"DaisyUIComponents.Stat","doc":"Stat component\n\nhttps://daisyui.com/components/stat","ref":"DaisyUIComponents.Stat.html"},{"type":"function","title":"DaisyUIComponents.Stat.directions/0","doc":"","ref":"DaisyUIComponents.Stat.html#directions/0"},{"type":"function","title":"DaisyUIComponents.Stat.stat/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat/1","doc":"* `figure` - Accepts attributes:\n\n  * `class` (`:any`)\n* `title` - Accepts attributes:\n\n  * `class` (`:any`)\n* `value` - Accepts attributes:\n\n  * `class` (`:any`)\n* `desc` - Accepts attributes:\n\n  * `class` (`:any`)\n* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stat_actions/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat_actions/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat_actions/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_actions/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat_actions/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_actions/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stat_desc/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat_desc/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat_desc/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_desc/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat_desc/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_desc/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stat_figure/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat_figure/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat_figure/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_figure/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat_figure/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_figure/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stat_title/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat_title/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat_title/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_title/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat_title/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_title/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stat_value/1","doc":"","ref":"DaisyUIComponents.Stat.html#stat_value/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stat_value/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_value/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stat_value/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_value/1-slots"},{"type":"function","title":"DaisyUIComponents.Stat.stats/1","doc":"","ref":"DaisyUIComponents.Stat.html#stats/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Stat.stats/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stats/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Stat.stats/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stats/1-slots"},{"type":"module","title":"DaisyUIComponents.Swap","doc":"Select component\n\nhttps://daisyui.com/components/swap","ref":"DaisyUIComponents.Swap.html"},{"type":"function","title":"DaisyUIComponents.Swap.swap/1","doc":"Render a Swap component","ref":"DaisyUIComponents.Swap.html#swap/1"},{"type":"function","title":"Examples - DaisyUIComponents.Swap.swap/1","doc":"<.swap >\n      <:swap_on name=\"ON\" />\n      <:swap_off name=\"OFF\" />\n    </.swap>\n\nwith theme controller\n\n    <.swap >\n      <:controller>\n         \n      </:controller>\n      <:swap_on name=\"ON\" />\n      <:swap_off name=\"OFF\" />\n    </.swap>","ref":"DaisyUIComponents.Swap.html#swap/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Swap.swap/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `animation` (`:string`) - Must be one of `\"flip\"`, or `\"rotate\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Swap.html#swap/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Swap.swap/1","doc":"* `swap_on` - the child element that should be visible when checkbox is checked or when swap is active. Accepts attributes:\n\n  * `type` (`:string`) - Must be one of `\"label\"`, or `\"icon\"`.\n  * `name` (`:string`) (required)\n* `swap_off` - The child element that should be visible when checkbox is not checked or when swap is not active. Accepts attributes:\n\n  * `type` (`:string`) - Must be one of `\"label\"`, or `\"icon\"`.\n  * `name` (`:string`) (required)\n* `controller` - The swap input controller.","ref":"DaisyUIComponents.Swap.html#swap/1-slots"},{"type":"function","title":"DaisyUIComponents.Swap.swap_mode/1","doc":"","ref":"DaisyUIComponents.Swap.html#swap_mode/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Swap.swap_mode/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `mode` (`:string`) (required) - Must be one of `\"on\"`, or `\"off\"`.\n* `name` (`:string`) (required)\n* `type` (`:string`) - Defaults to `\"label\"`.","ref":"DaisyUIComponents.Swap.html#swap_mode/1-attributes"},{"type":"module","title":"DaisyUIComponents.Table","doc":"Table component\n\nhttps://daisyui.com/components/table/","ref":"DaisyUIComponents.Table.html"},{"type":"function","title":"DaisyUIComponents.Table.table/1","doc":"Renders a table with generic styling.","ref":"DaisyUIComponents.Table.html#table/1"},{"type":"function","title":"Examples - DaisyUIComponents.Table.table/1","doc":"<.table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\"><%= user.id %></:col>\n      <:col :let={user} label=\"username\"><%= user.username %></:col>\n    </.table>\n\nor declaring the table components\n\n  <.table id=\"users\">\n    <.thead>\n      <.tr>\n        <.th>id</.th>\n        <.th>username</.th>\n      </.tr>\n    </.thead>\n    <.tbody>\n      <.tr :for={user <- @users}>\n        <.td><%= user.id %></.td>\n        <.td><%= user.username %></.td>\n      </.tr>\n    </.tbody>\n  </.table>","ref":"DaisyUIComponents.Table.html#table/1-examples"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.table/1","doc":"* `id` (`:string`) - Defaults to `nil`.\n* `class` (`:any`) - Defaults to `nil`.\n* `rows` (`:list`)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.\n* `zebra` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#table/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.table/1","doc":"* `col` - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.\n* `inner_block`","ref":"DaisyUIComponents.Table.html#table/1-slots"},{"type":"function","title":"DaisyUIComponents.Table.tbody/1","doc":"","ref":"DaisyUIComponents.Table.html#tbody/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.tbody/1","doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#tbody/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.tbody/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#tbody/1-slots"},{"type":"function","title":"DaisyUIComponents.Table.td/1","doc":"","ref":"DaisyUIComponents.Table.html#td/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.td/1","doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#td/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.td/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#td/1-slots"},{"type":"function","title":"DaisyUIComponents.Table.th/1","doc":"","ref":"DaisyUIComponents.Table.html#th/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.th/1","doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#th/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.th/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#th/1-slots"},{"type":"function","title":"DaisyUIComponents.Table.thead/1","doc":"","ref":"DaisyUIComponents.Table.html#thead/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.thead/1","doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#thead/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.thead/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#thead/1-slots"},{"type":"function","title":"DaisyUIComponents.Table.tr/1","doc":"","ref":"DaisyUIComponents.Table.html#tr/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Table.tr/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `active` (`:boolean`) - Defaults to `false`.\n* `hover` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#tr/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Table.tr/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#tr/1-slots"},{"type":"module","title":"DaisyUIComponents.TextInput","doc":"TextInput component\n\nhttps://daisyui.com/components/input","ref":"DaisyUIComponents.TextInput.html"},{"type":"function","title":"DaisyUIComponents.TextInput.text_input/1","doc":"","ref":"DaisyUIComponents.TextInput.html#text_input/1"},{"type":"function","title":"Attributes - DaisyUIComponents.TextInput.text_input/1","doc":"* `type` (`:string`) - Defaults to `\"text\"`.\n* `class` (`:string`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"value\"]`.","ref":"DaisyUIComponents.TextInput.html#text_input/1-attributes"},{"type":"module","title":"DaisyUIComponents.Textarea","doc":"Textarea component\n\nhttps://daisyui.com/components/textarea","ref":"DaisyUIComponents.Textarea.html"},{"type":"function","title":"DaisyUIComponents.Textarea.textarea/1","doc":"","ref":"DaisyUIComponents.Textarea.html#textarea/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Textarea.textarea/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Textarea.html#textarea/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Textarea.textarea/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Textarea.html#textarea/1-slots"},{"type":"module","title":"DaisyUIComponents.Toggle","doc":"Stat component\n\nhttps://daisyui.com/components/toggle","ref":"DaisyUIComponents.Toggle.html"},{"type":"function","title":"DaisyUIComponents.Toggle.toggle/1","doc":"","ref":"DaisyUIComponents.Toggle.html#toggle/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Toggle.toggle/1","doc":"* `class` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"checked\"]`.","ref":"DaisyUIComponents.Toggle.html#toggle/1-attributes"},{"type":"module","title":"DaisyUIComponents.Tooltip","doc":"Tooltip component\n\nhttps://daisyui.com/components/tooltip","ref":"DaisyUIComponents.Tooltip.html"},{"type":"function","title":"DaisyUIComponents.Tooltip.tooltip/1","doc":"","ref":"DaisyUIComponents.Tooltip.html#tooltip/1"},{"type":"function","title":"Attributes - DaisyUIComponents.Tooltip.tooltip/1","doc":"* `class` (`:string`) - Defaults to `nil`.\n* `text` (`:string`) (required)\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `direction` (`:string`) - Must be one of `\"top\"`, `\"bottom\"`, `\"left\"`, or `\"right\"`.\n* `open` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Tooltip.html#tooltip/1-attributes"},{"type":"function","title":"Slots - DaisyUIComponents.Tooltip.tooltip/1","doc":"* `inner_block`","ref":"DaisyUIComponents.Tooltip.html#tooltip/1-slots"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}